@@ -43,7 +43,7 @@ pub(super) async fn receive_batch_multipart(
     boundary: impl Into<String>,
     opts: MultipartOptions,
 ) -> Result<BatchRequest, ParseRequestError> {
-    let mut multipart = Multipart::new_with_constraints(
+    let mut multipart = Multipart::with_constraints(
         ReaderStream::new(body),
         boundary,
         Constraints::new().size_limit({
